==> ackee-frontend-toolkit-0.6.4.tgz: package/es/modules/chat/sagas.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _marked = /*#__PURE__*/regeneratorRuntime.mark(sendMessage),
    _marked2 = /*#__PURE__*/regeneratorRuntime.mark(createTextMessage),
    _marked3 = /*#__PURE__*/regeneratorRuntime.mark(setSeenMessages),
    _marked4 = /*#__PURE__*/regeneratorRuntime.mark(_callee);

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { effectSelect as select, effectPut as put, effectAll as all, effectTakeEvery as takeEvery, runSagas, getFirebase, _isEmpty } from './dependencies';

// import { uploadImage } from 'ackee-image-server';

import actionTypes from './actionTypes';
import * as chatActions from './actions';
import * as paths from './firebase/paths';

import { unseenSelector, messagesSelector } from './selectors';

export function sendMessage(conversationId, message, unseen, reset) {
    var _getFirebase$database;

    var key;
    return regeneratorRuntime.wrap(function sendMessage$(_context) {
        while (1) {
            switch (_context.prev = _context.next) {
                case 0:
                    if (!(typeof reset === 'function')) {
                        _context.next = 3;
                        break;
                    }

                    _context.next = 3;
                    return reset();

                case 3:
                    key = getFirebase().database().ref(paths.conversationMessages(conversationId).path).push().key;
                    _context.next = 6;
                    return getFirebase().database().ref().update((_getFirebase$database = {}, _defineProperty(_getFirebase$database, paths.conversationMessages(conversationId).path + '/' + key, _extends({}, message, {
                        unseen: unseen
                    })), _defineProperty(_getFirebase$database, paths.conversationLastMessage(conversationId).path, message), _getFirebase$database));

                case 6:
                    _context.next = 8;
                    return put(chatActions.setSeenMessages(conversationId));

                case 8:
                    _context.next = 10;
                    return put(chatActions.incSentMessages());

                case 10:
                case 'end':
                    return _context.stop();
            }
        }
    }, _marked, this);
}

export function createTextMessage(params) {
    var _params$data, userId, conversationId, text, reset, startSubmit, stopSubmit, unseen, message;

    return regeneratorRuntime.wrap(function createTextMessage$(_context2) {
        while (1) {
            switch (_context2.prev = _context2.next) {
                case 0:
                    _params$data = params.data, userId = _params$data.userId, conversationId = _params$data.conversationId, text = _params$data.text, reset = params.reset, startSubmit = params.startSubmit, stopSubmit = params.stopSubmit;
                    _context2.next = 3;
                    return select(unseenSelector, { userId: userId, conversationId: conversationId });

                case 3:
                    unseen = _context2.sent;
                    message = {
                        author: userId,
                        time: new Date().getTime(),
                        text: text
                    };
                    _context2.next = 7;
                    return sendMessage(conversationId, message, unseen(conversationId), reset);

                case 7:
                case 'end':
                    return _context2.stop();
            }
        }
    }, _marked2, this);
}
/*
function* createImageMessage(params) {
    const { image, conversationId } = params;
    const name = new Date().getTime().toString() + conversationId;
    try {
        const uploadedImage = yield uploadImage(
            config.imageServer.apiUrl,
            config.imageServer.apiKey,
            config.imageServer.folder + name.replace(/[_,.-]/g, ''),
            image,
        );
        const user = yield select(authUser);
        const unseen = yield select(unseenSelector);
        const message = {
            author: getUserFirebaseId(user),
            time: new Date().getTime(),
            image: uploadedImage.key,
        };
        yield sendMessage(conversationId, message, unseen(conversationId));
    } catch (e) {
        yield put(appActions.setErrorAlert(
            'alerts.chat.image.upload.error',
        ));
        yield put(loggingActions.logError(e));
        throw e;
    }
}
*/
export function setSeenMessages(_ref) {
    var conversationId = _ref.conversationId,
        userId = _ref.userId;

    var ref, _ref2, messages, refs;

    return regeneratorRuntime.wrap(function setSeenMessages$(_context3) {
        while (1) {
            switch (_context3.prev = _context3.next) {
                case 0:
                    ref = '' + paths.conversationMessages(conversationId).path;
                    _context3.next = 3;
                    return select(messagesSelector, { userId: userId, conversationId: conversationId });

                case 3:
                    _ref2 = _context3.sent;
                    messages = _ref2.messages;

                    if (!(messages && userId)) {
                        _context3.next = 10;
                        break;
                    }

                    refs = messages.reduce(function (allRefs, message) {
                        if (message.unseen[userId] !== undefined) {
                            allRefs['/' + message.messageId + '/unseen/' + userId] = null;
                        }
                        return allRefs;
                    }, {});

                    if (_isEmpty(refs)) {
                        _context3.next = 10;
                        break;
                    }

                    _context3.next = 10;
                    return getFirebase().database().ref(ref).update(refs);

                case 10:
                case 'end':
                    return _context3.stop();
            }
        }
    }, _marked3, this);
}

var handlers = _defineProperty({}, actionTypes.CREATE_TEXT_MESSAGE, createTextMessage);

export default function _callee() {
    return regeneratorRuntime.wrap(function _callee$(_context4) {
        while (1) {
            switch (_context4.prev = _context4.next) {
                case 0:
                    _context4.next = 2;
                    return all([runSagas(handlers), takeEvery(actionTypes.SET_SEEN_MESSAGES, setSeenMessages)]);

                case 2:
                    return _context4.abrupt('return', _context4.sent);

                case 3:
                case 'end':
                    return _context4.stop();
            }
        }
    }, _marked4, this);
}

==> ackee-frontend-toolkit-0.7.0.tgz: package/es/modules/chat/sagas.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _marked = /*#__PURE__*/regeneratorRuntime.mark(sendMessage),
    _marked2 = /*#__PURE__*/regeneratorRuntime.mark(createTextMessage),
    _marked3 = /*#__PURE__*/regeneratorRuntime.mark(setSeenMessages),
    _marked4 = /*#__PURE__*/regeneratorRuntime.mark(_callee);

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { effectSelect as select, effectPut as put, effectAll as all, effectTakeEvery as takeEvery, runSagas, getFirebase, _isEmpty, _get } from './dependencies';

import actionTypes from './actionTypes';
import * as chatActions from './actions';
import * as paths from './firebase/paths';

import { unseenSelector, messagesSelector } from './selectors';

export function sendMessage(conversationId, message, unseen, reset) {
    var _getFirebase$database;

    var key;
    return regeneratorRuntime.wrap(function sendMessage$(_context) {
        while (1) {
            switch (_context.prev = _context.next) {
                case 0:
                    if (!(typeof reset === 'function')) {
                        _context.next = 3;
                        break;
                    }

                    _context.next = 3;
                    return reset();

                case 3:
                    key = getFirebase().database().ref(paths.conversationMessages(conversationId).path).push().key;
                    _context.next = 6;
                    return getFirebase().database().ref().update((_getFirebase$database = {}, _defineProperty(_getFirebase$database, paths.conversationMessages(conversationId).path + '/' + key, _extends({}, message, {
                        unseen: unseen
                    })), _defineProperty(_getFirebase$database, paths.conversationLastMessage(conversationId).path, message), _getFirebase$database));

                case 6:
                    _context.next = 8;
                    return put(chatActions.setSeenMessages(conversationId));

                case 8:
                    _context.next = 10;
                    return put(chatActions.incSentMessages());

                case 10:
                case 'end':
                    return _context.stop();
            }
        }
    }, _marked, this);
}

export function createTextMessage(params) {
    var _params$data, userId, conversationId, text, reset, startSubmit, stopSubmit, unseen, message;

    return regeneratorRuntime.wrap(function createTextMessage$(_context2) {
        while (1) {
            switch (_context2.prev = _context2.next) {
                case 0:
                    _params$data = params.data, userId = _params$data.userId, conversationId = _params$data.conversationId, text = _params$data.text, reset = params.reset, startSubmit = params.startSubmit, stopSubmit = params.stopSubmit;
                    _context2.next = 3;
                    return select(unseenSelector, { userId: userId, conversationId: conversationId });

                case 3:
                    unseen = _context2.sent;
                    message = {
                        author: userId,
                        time: new Date().getTime(),
                        text: text
                    };
                    _context2.next = 7;
                    return sendMessage(conversationId, message, unseen(conversationId), reset);

                case 7:
                case 'end':
                    return _context2.stop();
            }
        }
    }, _marked2, this);
}

export function setSeenMessages(_ref) {
    var conversationId = _ref.conversationId,
        userId = _ref.userId;

    var ref, _ref2, messages, refs;

    return regeneratorRuntime.wrap(function setSeenMessages$(_context3) {
        while (1) {
            switch (_context3.prev = _context3.next) {
                case 0:
                    ref = '' + paths.conversationMessages(conversationId).path;
                    _context3.next = 3;
                    return select(messagesSelector, { userId: userId, conversationId: conversationId });

                case 3:
                    _ref2 = _context3.sent;
                    messages = _ref2.messages;

                    if (!(messages && userId)) {
                        _context3.next = 10;
                        break;
                    }

                    refs = messages.reduce(function (allRefs, message) {
                        if (_get(message, ['unseen', userId]) !== undefined) {
                            allRefs['/' + message.messageId + '/unseen/' + userId] = null;
                        }
                        return allRefs;
                    }, {});

                    if (_isEmpty(refs)) {
                        _context3.next = 10;
                        break;
                    }

                    _context3.next = 10;
                    return getFirebase().database().ref(ref).update(refs);

                case 10:
                case 'end':
                    return _context3.stop();
            }
        }
    }, _marked3, this);
}

var handlers = _defineProperty({}, actionTypes.CREATE_TEXT_MESSAGE, createTextMessage);

export default function _callee() {
    return regeneratorRuntime.wrap(function _callee$(_context4) {
        while (1) {
            switch (_context4.prev = _context4.next) {
                case 0:
                    _context4.next = 2;
                    return all([runSagas(handlers), takeEvery(actionTypes.SET_SEEN_MESSAGES, setSeenMessages)]);

                case 2:
                    return _context4.abrupt('return', _context4.sent);

                case 3:
                case 'end':
                    return _context4.stop();
            }
        }
    }, _marked4, this);
}
